Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Backup ¶
func Backup(opts BackupOpts) error
Backup backs up a bpf object, such as bpf program, bpf map or bpf link.
Types ¶
type BackupOpts ¶
type BackupOpts struct {
// Src is the path to the bpf object to be backed up.
Src string
// UnpinSrc specifies whether to unpin the bpf object after backing up.
UnpinSrc bool
// Dst is the path to the directory where the bpf object will be pinned to.
Dst string
// AutoMountBpffs specifies whether to automatically mount bpffs at:
// 1. BpffsPath if it is not empty and not already mounted.
// 2. Dirname(Dst) if BpffsPath is empty.
AutoMountBpffs bool
// BpffsPath is the path to the backup directory where bpffs is mounted.
BpffsPath string
}
BackupOpts specifies the options for backing up a bpf object.
Click to show internal directories.
Click to hide internal directories.